<?php
/**
 * Outputs the customizer styles.
 *
 * @package fad
 * @since 3.0.0
 */

/**
 * Outputs the custom styles for the theme.
 *
 * @return void
 */
function fad_custom_color_styles() {
	$accent_color     = get_theme_mod( 'fad_colors_accent', '#CB2C8C' );
	$alt_accent_color = get_theme_mod( 'fad_colors_alt_accent', '#1B1017' );
	$page_header_text_color = fad_get_contrast_text_color( '#' . get_background_color(), '#222222' );

	$custom_css = "
		a {
			border-bottom-color: {$accent_color};
			color: {$accent_color};
		}

		a:hover {
			border-bottom-color: {$alt_accent_color};
			color: {$alt_accent_color};
		}

		.btn,
		button,
		input[type=submit],
		input[type=button],
		.main-navigation .menu li.call-to-action a,
		.more-link,
		.home-section.fad-instagram #sb_instagram .sbi_follow_btn a,
		.comment-reply-link {
			background-color: {$accent_color};
			border-color: {$accent_color};
		}

		.btn:hover,
		button:hover,
		input[type=submit]:hover,
		input[type=button]:hover,
		.main-navigation .menu li.call-to-action a:hover,
		.more-link:hover,
		.home-section.fad-instagram #sb_instagram .sbi_follow_btn a:hover,
		.comment-reply-link:hover {
			background-color: {$alt_accent_color};
			border-color: {$alt_accent_color};
		}

		.site-header a:hover,
		.hentry .entry-header a:hover,
		.hentry .entry-meta a:hover,
		.widget-area.sidebar .widget a:hover,
		.hentry .entry-header .entry-title a:hover {
			color: {$accent_color};
		}

		.site-header-business .main-navigation,
		.site-header-blog .main-navigation,
		.tagcloud a:hover,
		.pagination .nav-links .page-numbers.current,
		.pagination .nav-links .page-numbers:hover,
		.pagination .nav-links .page-numbers.next:hover,
		.pagination .nav-links .page-numbers.prev:hover {
			background-color: {$accent_color};
		}

		.bypostauthor .comment-meta .avatar{
	   		border-color: {$accent_color};
	   	}

		.page-header,
		.page-template-elementor .entry-header {
			color: {$page_header_text_color};
		}

		.widget-area.sidebar .widget .widget_title:after {
			border: 1px solid {$accent_color};
		}

		@media ( min-width: 992px ) {
			.site-header-business .main-navigation .sub-menu a:hover,
			.site-header-blog .main-navigation .sub-menu a:hover {
				color: {$accent_color};
			}
		}
	";

	wp_add_inline_style( 'fad-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'fad_custom_color_styles', 100 );

/**
 * Outputs the custom styles for the theme.
 *
 * @return void
 */
function fad_custom_typography_styles() {
	$fonts        = fad_get_selected_fonts();
	$body_font    = $fonts['body'];
	$heading_font = $fonts['heading'];

	$custom_css = "
		button,
		body,
		input,
		select,
		textarea {
			font-family: '{$body_font}', serif;
		}

		.h1, h1,
		.h2, h2,
		.h3, h3,
		.h4, h4,
		.h5, h5,
		.h6, h6,
		.btn,
		button,
		input[type=button],
		.comment-meta .fn,
		.site-footer {
			font-family: '{$heading_font}', serif;
		}
	";

	wp_add_inline_style( 'fad-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'fad_custom_typography_styles', 100 );


/**
 * Outputs the custom styles for home page.
 *
 * @return void
 */
function fad_custom_homepage_styles() {
	$hero_overlay_color   = get_theme_mod( 'fad_home_hero_area_overlay_color', '#000000' );
	$hero_overlay_opacity = get_theme_mod( 'fad_home_hero_area_overlay_opacity', '0.6' );
	$hero_text_color      = fad_get_contrast_text_color( $hero_overlay_color, '#222222' );
	$hero_bg_image        = wp_get_attachment_image_src( get_theme_mod( 'fad_home_hero_area_bg_image' ), 'full' );

	$custom_css = "
		.page-template-homepage .home-section.hero,
		.page-template-homepage-premium .home-section.hero {
			background-image: url({$hero_bg_image[0]});
			color: $hero_text_color;
		}
		.page-template-homepage .home-section.hero:before,
		.page-template-homepage-premium .home-section.hero:before {
			background-color: {$hero_overlay_color};
			opacity: {$hero_overlay_opacity};
		}
	";

	$recent_posts_overlay_color   = get_theme_mod( 'fad_home_recent_posts_overlay_color', '#EAEAEA' );
	$recent_posts_overlay_opacity = get_theme_mod( 'fad_home_recent_posts_overlay_opacity', '1' );
	$recent_posts_text_color      = fad_get_contrast_text_color( $recent_posts_overlay_color, '#222222' );
	$recent_posts_bg_image        = wp_get_attachment_image_src( get_theme_mod( 'fad_home_recent_posts_bg_image' ), 'full' );

	$custom_css .= "
		.page-template-homepage .home-section.recent-posts,
		.page-template-homepage-premium .home-section.recent-posts {
			background-image: url({$recent_posts_bg_image[0]});
			color: $recent_posts_text_color;
		}
		.page-template-homepage .home-section.recent-posts:before,
		.page-template-homepage-premium .home-section.recent-posts:before {
			background-color: {$recent_posts_overlay_color};
			opacity: {$recent_posts_overlay_opacity};
		}
	";

	wp_add_inline_style( 'fad-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'fad_custom_homepage_styles', 100 );

/**
 * Adds custom classes to body for header/content layout.
 *
 * @param  array $classes The default body classes.
 * @return array          Body classes with custom classes added.
 */
function fad_custom_body_class( $classes ) {
	$full_width_header = get_theme_mod( 'fad_full_width_header', false );
	if ( $full_width_header ) {
		$classes[] = 'full-width-header';
	}

	$sidebar_layout = get_theme_mod( 'fad_sidebar_layout', 'default' );
	if ( 'default' !== $sidebar_layout ) {
		$classes[] = 'sidebar-layout-' . $sidebar_layout;
	}

	return $classes;
}
add_filter( 'body_class', 'fad_custom_body_class' );

/**
 * Outputs the custom styles for blog, archive and search pages.
 *
 * @return void
 */
function fad_custom_default_pages_styles() {
	$fad_pages_title_image        = wp_get_attachment_image_src( get_theme_mod( 'fad_pages_title_image' ), 'full' );

	$custom_css = "
		.blog .page-title:before,
		.archive .page-title:before,
		.search .page-title:before {
			content: url({$fad_pages_title_image[0]});
		}
	";

	wp_add_inline_style( 'fad-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'fad_custom_default_pages_styles', 100 );
